﻿/********************************
 * 
 * autor: Marcin Pietrzykowski
 * mail: mpietrzykowski@wi.zut.edu.pl
 * 
 * ******************************/

using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;

using MatlabUtils;

namespace MatlabUtilsTest {
    class Program {
        static void Main(string[] args) {
            using (MatlabInstance matlab = new MatlabInstance(ServerMode.Single)) {
                Random rnd = new Random();
                uint figureNo = 1;
                double step = 0.1;
                double val;
                int count = (int)(Math.PI / step + 1);
                double[] x = new double[2 * count];
                double[] y = new double[2 * count];

                val = 0.0;
                for (int i = 0; i < x.Length; ++i, val += step) {
                    x[i] = val;
                    y[i] = Math.Sin(val);
                }


                matlab.Points(x, y);
                matlab.GridOn();

                matlab.Figure(++figureNo);
                matlab.Plot(x, y, "'g'");
                matlab.Text(Math.PI, 0, @" \leftarrow sin(\pi)", "'FontSize', 18");
                matlab.XLabel("x");
                matlab.YLabel("y");
                matlab.Title("Wykres");

                matlab.Figure(++figureNo);
                matlab.Area(x, y);

                matlab.Figure(++figureNo);
                matlab.PolarFromCartesianCoordinates(x, y, Math.PI, 0.0);


                double[] t = x;
                double[] r = new double[t.Length];
                for (int i = 0; i < t.Length; ++i) {
                    r[i] = Math.Sin(2 * t[i]) * Math.Cos(2 * t[i]);
                }

                matlab.Figure(++figureNo);
                matlab.Polar(t, r, "'--r'");

                for (int i = 0; i < x.Length; ++i) {
                    x[i] = rnd.Next(360);
                }
                matlab.Figure(++figureNo);
                matlab.Rose(x, 9);


                for (int i = 0; i < x.Length; ++i) {
                    x[i] = rnd.Next(10);
                }
                matlab.Figure(++figureNo);
                matlab.Bar(x, "'r'");

                matlab.Figure(++figureNo);
                matlab.Hist(x, 5);

                matlab.Figure(++figureNo);
                matlab.Hist(x, new double[3] { 2, 7, 8 });

                x = new double[10];
                y = new double[10];
                for (int i = 0; i < x.Length; ++i) {
                    x[i] = rnd.NextDouble() - 0.5;
                    y[i] = rnd.NextDouble() - 0.5;
                }
                matlab.Figure(++figureNo);
                matlab.Compass(x, y);

                x = new double[10 * count];
                y = new double[10 * count];
                double[] z = new double[10 * count];

                val = 0.0;
                for (int i = 0; i < x.Length; ++i, val += step) {
                    x[i] = Math.Sin(val);
                    y[i] = Math.Cos(val);
                    z[i] = val;
                }

                matlab.Figure(++figureNo);
                matlab.Points(x, y, z);
                matlab.XLabel("x");
                matlab.YLabel("y");
                matlab.ZLabel("z");
                matlab.Title("Wykres");
                matlab.GridOn();

                matlab.Figure(++figureNo);
                matlab.Plot(x, y, z);
                matlab.GridOn();

                int count2 = 4;
                x = new double[count2];
                y = new double[count2];
                z = new double[count2];

                for (int i = 0; i < x.Length; ++i) {
                    x[i] = rnd.Next(10);
                    y[i] = rnd.Next(10);
                    z[i] = rnd.Next(10);
                }


                double[,] xx = new double[count, count];
                double[,] yy = new double[count, count];
                double[,] zz = new double[count, count];

                val = 0.0;              
                for (int i = 0; i < count; ++i, val += step) {
                    for (int j = 0; j < count; ++j) {
                        xx[i, j] = val;
                        yy[j, i] = val;
                    }
                }

                for (int i = 0; i < count; ++i, val += step) {
                    for (int j = 0; j < count; ++j) {
                        zz[i, j] = Math.Cos(xx[i, j] * yy[i, j]) * Math.Cos(xx[i, j]);
                    }
                }

                matlab.Figure(++figureNo);
                matlab.Mesh(xx, yy, zz);
                matlab.Figure(++figureNo);
                matlab.MeshContour(xx, yy, zz);
                matlab.Figure(++figureNo);
                matlab.Surf(xx, yy, zz);
                matlab.Figure(++figureNo);
                matlab.SurfContour(xx, yy, zz);
                matlab.Figure(++figureNo);
                matlab.Contour(xx, yy, zz);
                matlab.Figure(++figureNo);
                matlab.Contour(xx, yy, zz, 3);
                matlab.Figure(++figureNo);
                matlab.ContourFilled(xx, yy, zz);
                matlab.Figure(++figureNo);
                matlab.ContourFilled(xx, yy, zz, 20);
                matlab.Figure(++figureNo);
                matlab.Ribbon(zz);
                matlab.Figure(++figureNo);
                matlab.Ribbon(xx, zz);
                matlab.Figure(++figureNo);
                matlab.Waterfall(xx, yy, zz);

                Console.WriteLine("Wciśnij dowolny klawisz...");
                Console.ReadKey();

                matlab.CloseFiguresAndClearAll();                
            }
        }
    }
}

